@@ -6,6 +6,7 @@ from io import BytesIO
 
 import openpyxl
 from openpyxl.utils import get_column_letter
+from openpyxl.utils.exceptions import InvalidFileException
 
 import xlrd
 import xlwt
@@ -178,22 +179,24 @@ class Files:
             book = XlsxWorkbook(path)
             book.open()
             return book
-        except Exception as err:
-            self.logger.debug(err)
-
-        self.logger.info(
-            "Failed to open in Office Open XML (.xlsx) format, "
-            "trying Excel Binary Format (.xls)"
-        )
+        except InvalidFileException as exc:
+            self.logger.debug(exc)  # Unsupported extension, silently try xlrd
+        except Exception as exc:
+            self.logger.info(
+                "Failed to open as Office Open XML (.xlsx) format: %s", exc
+            )
 
         try:
             book = XlsWorkbook(path)
             book.open()
             return book
-        except Exception as err:
-            self.logger.debug(err)
+        except Exception as exc:
+            self.logger.info("Failed to open as Excel Binary Format (.xls): %s", exc)
 
-        raise ValueError(f"Not a valid Excel file: {path}")
+        raise ValueError(
+            f"Failed to open Excel file ({path}), "
+            "verify that the path and extension are correct"
+        )
 
     def create_workbook(self, path=None, fmt="xlsx"):
         """Create and open a new Excel workbook.
@@ -362,13 +365,23 @@ class Files:
         assert self.workbook, "No active workbook"
         return self.workbook.find_empty_row(name)
 
+    def get_worksheet_value(self, row, column, name=None):
+        """Get a cell value in the given worksheet.
+
+        :param row:     Index of row to read, e.g. 3
+        :param column:  Name or index of column, e.g. C or 7
+        :param name:    Name of worksheet (optional)
+        """
+        assert self.workbook, "No active workbook"
+        return self.workbook.get_cell_value(row, column, name)
+
     def set_worksheet_value(self, row, column, value, name=None):
         """Set a cell value in the given worksheet.
 
         :param row:     Index of row to write, e.g. 3
         :param column:  Name or index of column, e.g. C or 7
         :param value:   New value of cell
-        :param name:    Name of worksheet
+        :param name:    Name of worksheet (optional)
         """
         assert self.workbook, "No active workbook"
         self.workbook.set_cell_value(row, column, value, name)
@@ -574,6 +587,13 @@ class XlsxWorkbook:
 
         return 1
 
+    def get_cell_value(self, row, column, name=None):
+        name = self._get_sheetname(name)
+        sheet = self._book[name]
+        cell = self._get_cellname(row, column)
+
+        return sheet[cell].value
+
     def set_cell_value(self, row, column, value, name=None):
         name = self._get_sheetname(name)
         sheet = self._book[name]
@@ -693,17 +713,7 @@ class XlsWorkbook:
             options["filename"] = path_or_file
             extension = pathlib.Path(path_or_file).suffix
 
-        try:
-            self._book = xlrd.open_workbook(**options)
-        except NotImplementedError:
-            del options["formatting_info"]
-            self._book = xlrd.open_workbook(**options)
-
-            if extension == ".xls":
-                self.logger.warning(
-                    "Workbook '%s' file extension does not match content", path_or_file
-                )
-
+        self._book = xlrd.open_workbook(**options)
         self._extension = extension
         self._images = []
 
@@ -851,6 +861,13 @@ class XlsWorkbook:
 
         return 1
 
+    def get_cell_value(self, row, column, name=None):
+        name = self._get_sheetname(name)
+        sheet = self._book.sheet_by_name(name)
+        row, column = self._get_cell(row, column)
+
+        return sheet.cell_value(row, column)
+
     def set_cell_value(self, row, column, value, name=None):
         name = self._get_sheetname(name)
         row, column = self._get_cell(row, column)
